@@ -150,7 +150,7 @@ int main(int argc, char* argv[]) {
                 exit_version();
                 break;
             case 'f':
-                sfile = (char*)malloc((strlen(optarg) + 1) * sizeof(sfile));
+                sfile = (char*)malloc((strlen(optarg) + 1) * sizeof(char));
                 strcpy(sfile, optarg);
                 break;
             case 203:
