@@ -7,18 +7,17 @@
    file COPYING provided in this package for details.
 */
 
+#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 
-#include <config.h>
-#include <deborphan.h>
-#include <errno.h>
+#include "config.h"
+#include "deborphan.h"
 
 /* This uses up as much memory as your status file (near a
  * megabyte). It is considerably faster, though.
