@@ -15,13 +15,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-
 #include <sys/mman.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 
-#include <deborphan.h>
+#include "deborphan.h"
 
 /* If package is a valid package, this function returns 0. On error, it
  * returns -1, if it is not a valid package, it returns the position in
@@ -130,15 +129,23 @@ int addkeep(const char* kfile, char** add) {
         error(EXIT_FAILURE, errno, "Opening %s", kfile);
     }
 
-    // ... check if the final newline is missing ...
-    if (fseek(fp, -1L, SEEK_END) < 0) {
+    if (fseek(fp, 0L, SEEK_END) < 0) {
         error(EXIT_FAILURE, errno, "fseek on %s", kfile);
     }
-    c = fgetc(fp);
-    fseek(fp, 0L, SEEK_END);
-    if (c != EOF && c != '\n') {
-        // ... and add '\n' if appropriate.
-        fputc('\n', fp);
+
+    if (ftell(fp) != 0L) {
+        // ... check if the final newline is missing ...
+        if (fseek(fp, -1L, SEEK_END) < 0) {
+            error(EXIT_FAILURE, errno, "fseek on %s", kfile);
+        }
+        c = fgetc(fp);
+        if (fseek(fp, 0L, SEEK_END) < 0) {
+            error(EXIT_FAILURE, errno, "fseek on %s", kfile);
+        }
+        if (c != EOF && c != '\n') {
+            // ... and add '\n' if appropriate.
+            fputc('\n', fp);
+        }
     }
 
     int i = 0;
