@@ -65,7 +65,8 @@ void init_pkg_regex(void) {
             strcat(guess, "^lib.*-java$|");
         if (guess_chk(GUESS_SECTION)) {
             regcomp(&re_gnugrepv,
-                    "(-perl|-dev|-doc|-dbg)$|^lib(mono|pam|reoffice)|-(ruby[[:"
+                    "(-perl|-dev|-doc|-dbg)$|^lib(mono|pam|recad|reoffice)|-("
+                    "ruby[[:"
                     "digit:]"
                     ".]*|bin|tools|utils|dbg|dbgsym)$",
                     REG_EXTENDED | REG_FLAGS);
